@@ -10,4 +10,4 @@ class is_ctc_qualifying_child(Variable):
 
     def formula(person, period, parameters):
         age = person("age", period)
-        return age <= parameters(period).irs.credits.ctc.child.max_age
+        return age <= parameters(period).gov.irs.credits.ctc.child.max_age
