@@ -3,7 +3,7 @@ from openfisca_us.model_api import *
 
 class mo_income_tax_before_credits(Variable):
     value_type = float
-    entity = TaxUnit
+    entity = Person
     label = "Missouri income tax before credits"
     unit = USD
     definition_period = YEAR
@@ -13,7 +13,7 @@ class mo_income_tax_before_credits(Variable):
     )
     defined_for = StateCode.MO
 
-    def formula(tax_unit, period, parameters):
-        taxable_income = tax_unit("mo_taxable_income", period)
+    def formula(person, period, parameters):
+        taxable_income = person("mo_taxable_income", period)
         rates = parameters(period).gov.states.mo.tax.income.rates
         return rates.calc(taxable_income)
