@@ -13,6 +13,8 @@ class meets_snap_net_income_test(Variable):
     )
 
     def formula(spm_unit, period, parameters):
-        net_income_limit_fpg = parameters(period).usda.snap.income.limit.net
+        net_income_limit_fpg = parameters(
+            period
+        ).gov.usda.snap.income.limit.net
         net_income_fpg = spm_unit("snap_net_income_fpg_ratio", period)
         return net_income_fpg <= net_income_limit_fpg
